@@ -1,4 +1,5 @@
 import sys
+from inspect import getmembers, isfunction
 from typing import Any, Dict
 
 import appdirs
@@ -6,8 +7,6 @@ import pytest
 
 import platformdirs
 
-NEW_IN_PLATFORMDIRS = {"user_runtime_dir"}
-
 
 def test_has_backward_compatible_class() -> None:
     from platformdirs import AppDirs
@@ -15,6 +14,24 @@ def test_has_backward_compatible_class() -> None:
     assert AppDirs is platformdirs.PlatformDirs
 
 
+def test_has_all_functions() -> None:
+    # Get all public function names from appdirs
+    appdirs_function_names = [f[0] for f in getmembers(appdirs, isfunction) if not f[0].startswith("_")]
+
+    # Exception will be raised if any appdirs functions aren't in platformdirs.
+    for function_name in appdirs_function_names:
+        getattr(platformdirs, function_name)
+
+
+def test_has_all_properties() -> None:
+    # Get names of all the properties of appdirs.AppDirs
+    appdirs_property_names = [p[0] for p in getmembers(appdirs.AppDirs, lambda member: isinstance(member, property))]
+
+    # Exception will be raised if any appdirs.AppDirs properties aren't in platformdirs.AppDirs
+    for property_name in appdirs_property_names:
+        getattr(platformdirs.AppDirs, property_name)
+
+
 @pytest.mark.parametrize(
     "params",
     [
@@ -31,8 +48,10 @@ def test_has_backward_compatible_class() -> None:
     ],
 )
 def test_compatibility(params: Dict[str, Any], func: str) -> None:
-    if func in NEW_IN_PLATFORMDIRS:
+    # Only test functions that are part of appdirs
+    if getattr(appdirs, func, None) is None:
         pytest.skip(f"`{func}` does not exist in `appdirs`")
+
     if sys.platform == "darwin":
         msg = {  # pragma: no cover
             "user_log_dir": "without appname produces NoneType error",
